@@ -8,6 +8,37 @@ import json
 import pickle
 import pyarrow.parquet as pq
 import urllib
+import os
+import subprocess
+
+
+
+
+def azure_move_directory(src, dest):
+    SAS = AZURE_SAS
+    logger.info("moving blobs from original folder: "+str(src)+" to recovery folder on the same azure container: "+str(dest))
+    try:
+        comm = 'sudo azcopy cp "' + src + '?' + SAS + '" ' + '"' + dest + '?' + SAS + '" --recursive=true --overwrite=ifSourceNewer'
+        print(comm)
+        process = subprocess.Popen([comm],
+                                   stdout=subprocess.PIPE,
+                                   stderr=subprocess.PIPE,
+                                   shell=True)
+        stdout, stderr = process.communicate()
+        stdout, stderr
+
+        supp = 'sudo azcopy rm "' + src + '?' + SAS + '" --recursive=true'
+        print(supp)
+        process = subprocess.Popen([supp],
+                                   stdout=subprocess.PIPE,
+                                   stderr=subprocess.PIPE,
+                                   shell=True)
+        stdout, stderr = process.communicate()
+        stdout, stderr
+    except Exception as e:
+        logger.error(e)
+
+
 
 
 def upload_folder_into_azure(local_path, directory_path_azure):
