@@ -149,6 +149,11 @@ def download(url, filename):
     '''
     # As long as the file is opened in binary mode, both Python 2 and Python 3
     # can write response body to it without decoding.
+
+    opener = urllib.request.build_opener()
+    opener.addheaders = [('User-agent', 'Mozilla/5.0')]
+    urllib.request.install_opener(opener)
+
     try:
         res = all(ord(c) < 128 for c in url)
         if res:
@@ -241,7 +246,7 @@ def get_remote_file_hash(url, max_file_size=100 * 1024 * 1024):
 def image_extension(image_url):
     r = requests.head(image_url)
     if r.headers.get("content-type", None):
-        return r.headers.get("content-type", "").split('/')[1]
+        return r.headers.get("content-type", "/").split('/')[1]
     else:
         return image_url.split('.')[-1]
 
@@ -267,6 +272,11 @@ def download_resized_image(url, filename):
     # can write response body to it without decoding.
     logger.info("******** Downloading image..")
     start = time.process_time()
+
+    opener = urllib.request.build_opener()
+    opener.addheaders = [('User-agent', 'Mozilla/5.0')]
+    urllib.request.install_opener(opener)
+
     try:
         res = all(ord(c) < 128 for c in url)
         if res:
@@ -867,7 +877,7 @@ def count_product(token, url_shop):
     except:
         return 0
 
-
+#TO BE MODIFIED TO MATCH THE LATEST ONE AND TO BE IMPORTED EVERYWHERE NEEDED IN BACKEND
 def fine_tune(IMG_HEIGHT, IMG_WIDTH, NUM_CLASSES):
 
     vgg_conv = VGG16(weights='imagenet', include_top=False, input_shape=(IMG_HEIGHT, IMG_WIDTH, 3))
