@@ -190,22 +190,18 @@ def is_apikey_valid(user_apikey):
 
 
 def is_user_allowed(user_apikey):
-    dbase = PostgreSQL()
     try:
-        user = dbase.get_customer_from_apikey(apikey=user_apikey)[0]
+        user = db.get_customer_from_apikey(apikey=user_apikey)[0]
     except Exception as e:
         logger.error("exception ...................%s" % e)
         logger.error("APIKEY not found. Access forbidden for '" + str(user_apikey) + "'")
-        dbase.close_connection()
         return False
 
-    expiration = dbase.get_expiration_from_apikey(apikey=user_apikey)[0]
+    expiration = db.get_expiration_from_apikey(apikey=user_apikey)[0]
     if time.time() > expiration:
         logger.info("User '" + user + "' is not allowed because APIKEY has expired. Expiration date: " + time.ctime(
-            int(dbase.get_expiration_from_customer(user)[0])))
-        dbase.close_connection()
+            int(db.get_expiration_from_customer(user)[0])))
         return False
-    dbase.close_connection()
     return True
 
 
