@@ -1616,7 +1616,9 @@ def delete_project(customer, customer_type, api_project, project_name, project_i
     name = project_name + "_deleted" + datetime.date.today().strftime("%Y-%m-%d")
     db.update_status_name_deleted_project(name, 0, customer, customer_type, project_name, api_project)
 
+
     if project_name != "" and api_project == "similars":
+
         input_path_project_to_delete = INPUT_PATH + customer_type + '/' + customer + '/images/' + project_name
         output_path_project_to_delete = OUTPUT_PATH + customer_type + '/' + customer + '/images/' + project_name
         vectors_path_project_to_delete = VECTORS_PATH + customer_type + '/' + customer + '/' + project_name
@@ -1633,81 +1635,110 @@ def delete_project(customer, customer_type, api_project, project_name, project_i
         training_path_s3_to_delete = TRAININGS_S3 + customer_type + '/' + customer + '/classification/' + \
                                      project_name
 
-        vectors_path_azure = AZURE_VECTORS_PATH + customer_type + '/' + customer + '/' + project_name
-        output_path_azure = AZURE_OUTPUT_PATH + customer_type + '/' + customer + '/images/' + project_name
-        input_path_azure = AZURE_INPUT_PATH + customer_type + '/' + customer + '/images/' + project_name
-        streams_path_azure = AZURE_STREAMS_PATH + customer_type + '/' + customer + '/similars/' + \
+        vectors_path_azure = AZURE_CUSTOM_DOMAIN_BLOB + AZURE_CONTAINER_NAME + '/' + AZURE_VECTORS_PATH + customer_type + '/' + customer + '/' + project_name
+        output_path_azure = AZURE_CUSTOM_DOMAIN_BLOB + AZURE_CONTAINER_NAME + '/' + AZURE_OUTPUT_PATH + customer_type + '/' + customer + '/images/' + project_name
+        input_path_azure = AZURE_CUSTOM_DOMAIN_BLOB + AZURE_CONTAINER_NAME + '/' + AZURE_INPUT_PATH + customer_type + '/' + customer + '/images/' + project_name
+        streams_path_azure = AZURE_CUSTOM_DOMAIN_BLOB + AZURE_CONTAINER_NAME + '/' + AZURE_STREAMS_PATH + customer_type + '/' + customer + '/similars/' + \
                              project_name
-        training_path_azure = AZURE_TRAINING_PATH + customer_type + '/' + customer + '/classification/' + \
+        training_path_azure = AZURE_CUSTOM_DOMAIN_BLOB + AZURE_CONTAINER_NAME + '/' + AZURE_TRAINING_PATH + customer_type + '/' + customer + '/classification/' + \
                               project_name
+        input_path_azure_recovery = AZURE_CUSTOM_DOMAIN_BLOB + AZURE_CONTAINER_NAME + '/' + 'recovery_deleted_projects/' + 'input/' + \
+                                      customer_type + '/' + customer + '/images/' + project_name
+        output_path_azure_recovery = AZURE_CUSTOM_DOMAIN_BLOB + AZURE_CONTAINER_NAME + '/' + 'recovery_deleted_projects/' + 'output/' + \
+                                    customer_type + '/' + customer + '/images/' + project_name
+        vectors_path_azure_recovery = AZURE_CUSTOM_DOMAIN_BLOB + AZURE_CONTAINER_NAME + '/' + 'recovery_deleted_projects/' + 'vectors/' + \
+                                    customer_type + '/' + customer + '/similars/' + project_name
+        streams_path_azure_recovery = AZURE_CUSTOM_DOMAIN_BLOB + AZURE_CONTAINER_NAME + '/' + 'recovery_deleted_projects/' + 'streams/' + \
+                                    customer_type + '/' + customer + '/delta_files/' + project_name
+        training_path_azure_recovery = AZURE_CUSTOM_DOMAIN_BLOB + AZURE_CONTAINER_NAME + '/' + 'recovery_deleted_projects/' + 'trainings/' + \
+                                    customer_type + '/' + customer + '/classification/' + project_name
+
         try:
             if os.path.isdir(input_path_project_to_delete):
                 if USE_AWS:
                     move_directory(input_path_s3, 'deleted_project')
                 else:
-                    for file in list_repository_files(input_path_azure):
-                        copy_azure_file(file, AZURE_CONTAINER_NAME, "deleted-" + AZURE_CONTAINER_NAME)
-
+                    azure_move_directory(input_path_azure, input_path_azure_recovery)
                 shutil.rmtree(input_path_project_to_delete)
                 logger.info("input path -------- DELETED")
             if os.path.isdir(output_path_project_to_delete):
                 if USE_AWS:
                     move_directory(output_path_s3, 'deleted_project')
                 else:
-                    for file in list_repository_files(output_path_azure):
-                        copy_azure_file(file, AZURE_CONTAINER_NAME, "deleted-" + AZURE_CONTAINER_NAME)
+                    azure_move_directory(output_path_azure, output_path_azure_recovery)
                 shutil.rmtree(output_path_project_to_delete)
                 logger.info("output path -------- DELETED")
             if os.path.isdir(vectors_path_project_to_delete):
                 if USE_AWS:
                     move_directory(vectors_path_s3, 'deleted_project')
                 else:
-                    for file in list_repository_files(vectors_path_azure):
-                        copy_azure_file(file, AZURE_CONTAINER_NAME, "deleted-" + AZURE_CONTAINER_NAME)
+                    azure_move_directory(vectors_path_azure, vectors_path_azure_recovery)
                 shutil.rmtree(vectors_path_project_to_delete)
                 logger.info("vectors path -------- DELETED")
             if os.path.isdir(streams_path_project_similars_to_delete):
                 if USE_AWS:
                     move_directory(streams_path_3, 'deleted_project')
                 else:
-                    for file in list_repository_files(streams_path_azure):
-                        copy_azure_file(file, AZURE_CONTAINER_NAME, "deleted-" + AZURE_CONTAINER_NAME)
+                    azure_move_directory(streams_path_azure, streams_path_azure_recovery)
                 shutil.rmtree(streams_path_project_similars_to_delete)
                 logger.info("streams path similars -------- DELETED")
             if os.path.isdir(training_path_project_to_delete):
                 if USE_AWS:
                     move_directory(training_path_s3_to_delete, 'deleted_project')
                 else:
-                    for file in list_repository_files(training_path_azure):
-                        copy_azure_file(file, AZURE_CONTAINER_NAME, "deleted-" + AZURE_CONTAINER_NAME)
+                    azure_move_directory(training_path_azure, training_path_azure_recovery)
                 shutil.rmtree(training_path_project_to_delete)
                 logger.info("training classification path similars -------- DELETED")
             return 1
         except Exception as e:
             logger.info("Error deleting similars project %s %s " % (project_name, e))
             return 0
+
     elif project_name != "" and api_project == "classification":
+
         streams_path_project_classification_to_delete = STREAMS_PATH + customer_type + '/' + customer + \
-                                                        '/classification/' + project_name
+                                                        '/delta_files/' + project_name
         streams_path_s3_classification_to_delete = STREAMS_S3 + customer_type + '/' + customer + \
                                                    '/classification/' + project_name
         training_path_project_to_delete = TRAININGS_PATH + customer_type + '/' + customer + '/classification/' + \
                                           project_name
         training_path_s3_to_delete = TRAININGS_PATH + customer_type + '/' + customer + '/classification/' + \
                                      project_name
+
+        training_path_azure = AZURE_CUSTOM_DOMAIN_BLOB + AZURE_CONTAINER_NAME + '/' + AZURE_TRAINING_PATH + customer_type + '/' + customer + '/classification/' + \
+                              project_name
+        streams_path_azure = AZURE_CUSTOM_DOMAIN_BLOB + AZURE_CONTAINER_NAME + '/' + AZURE_STREAMS_PATH + customer_type + '/' + customer + '/similars/' + \
+                             project_name
+        training_path_azure_recovery = AZURE_CUSTOM_DOMAIN_BLOB + AZURE_CONTAINER_NAME + '/' + 'recovery_deleted_projects/' + 'trainings/' + \
+                                       customer_type + '/' + customer + '/classification/' + project_name
+        streams_path_azure_recovery = AZURE_CUSTOM_DOMAIN_BLOB + AZURE_CONTAINER_NAME + '/' + 'recovery_deleted_projects/' + 'streams/' + \
+                                      customer_type + '/' + customer + '/classification/' + project_name
+
         try:
-            if os.path.isdir(training_path_project_to_delete):
-                move_directory(training_path_s3_to_delete, 'deleted_project')
-                shutil.rmtree(training_path_project_to_delete)
-                logger.info("training path -------- DELETED")
-            if os.path.isdir(streams_path_project_classification_to_delete):
-                move_directory(streams_path_s3_classification_to_delete, 'deleted_project')
-                shutil.rmtree(streams_path_project_classification_to_delete)
-                logger.info("streams path classification -------- DELETED")
-            return 1
+            if USE_AWS:
+                if os.path.isdir(training_path_project_to_delete):
+                    move_directory(training_path_s3_to_delete, 'deleted_project')
+                    shutil.rmtree(training_path_project_to_delete)
+                    logger.info("training path -------- DELETED")
+                if os.path.isdir(streams_path_project_classification_to_delete):
+                    move_directory(streams_path_s3_classification_to_delete, 'deleted_project')
+                    shutil.rmtree(streams_path_project_classification_to_delete)
+                    logger.info("streams path classification -------- DELETED")
+                return 1
+            else:
+                if os.path.isdir(training_path_project_to_delete):
+                    azure_move_directory(training_path_azure, training_path_azure_recovery)
+                    shutil.rmtree(training_path_project_to_delete)
+                    logger.info("training path -------- DELETED")
+                if os.path.isdir(streams_path_project_classification_to_delete):
+                    azure_move_directory(streams_path_azure, streams_path_azure_recovery)
+                    shutil.rmtree(streams_path_project_classification_to_delete)
+                    logger.info("streams path classification -------- DELETED")
+                return 1
         except Exception as e:
             logger.info("Error deleting similars project %s %s " % (project_name, e))
             return 0
+
     elif project_name != "" and project_id and api_project == "detection_error":
         list_directories = ['labels', 'images', 'bottlenecks', 'model', 'model_text', 'output', 'predictCustomerPATH',
                             'tmp']
