@@ -118,7 +118,6 @@ def delta_retrieve_json(customer_name, customer_type, project_name):
         last_json = {customer_name + "_" + customer_type: []}
         before_last_json = {customer_name + "_" + customer_type: []}
     try:
-        print("*** delta: comparing last json file: "+last_json_path+" with: "+before_last_json_path)
         difference = diff(before_last_json, last_json)
     except Exception as e:
         logger.error("Error_diff %s" %e)
@@ -282,10 +281,10 @@ def max_nb_images(path):
     return max(list_nbrs)
 
 
-def verif_folder_less_twenty(path):
+def verif_folder_less_twenty(path, nb_classes):
     image_ext = ['.jpg', '.png', '.jpeg', '.JPG', '.PNG', '.JPEG']
     folder_less_20 = []
-    max_nb = max_nb_images(path)
+    max_nb = max(round(nb_classes // BATCH_SIZE),max_nb_images(path))
     if max_nb < 20:
         max_nb = 20
     for j in os.listdir(path):
