@@ -106,7 +106,7 @@ def get_similars_if_exist(user_apikey, customer_name, customer_type, project_nam
                                         'ip': ip
                                         },
                                message_body=body)
-        rpc_queue.close()
+
         return value.decode('utf-8')
 
 
@@ -126,7 +126,6 @@ def customer_authentication(customer_email, customer_password, body, type_user):
                                     'customer_password': customer_password},
                            message_body=body)
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -143,7 +142,6 @@ def get_api_key_expiration(customer_name, customer_type, user_apikey):
                                     'user_apikey': user_apikey},
                            message_body="")
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -162,7 +160,6 @@ def customer_inscription(customer_email, customer_type, customer_name, body, typ
                                     'user_apikey': ""},
                            message_body=body)
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -180,18 +177,6 @@ def process_customer_stream_from_json(user_apikey, customer_name, customer_type,
     my_queue_json.publish(body)
 
 
-def classfication_after_similars(user_apikey, customer_name, customer_type, project_name):
-    my_queue_json = RabbitMQ(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
-                             mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD,
-                             mqueue_name=MESSAGE_QUEUE_INPUT_NAME,
-                             headers={'user_apikey': user_apikey,
-                                      'operation': 'classfication_after_similars',
-                                      'customer_name': customer_name,
-                                      'customer_type': customer_type,
-                                      'project_name': project_name
-                                      })
-    my_queue_json.publish("")
-
 # Cms process
 def process_customer_stream_cms(user_apikey, customer_name, customer_type, project_name, body):
     my_queue_json = RabbitMQ(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
@@ -236,7 +221,6 @@ def text_training(user_apikey, customer_name, customer_type, customer_universe,
                                     'customer_universe': customer_universe},
                            message_body=body)
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -274,7 +258,6 @@ def predict_customer(user_apikey, customer_name, customer_type, customer_univers
                                     'customer_type': customer_type},
                            message_body=body)
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -288,7 +271,6 @@ def predict_image(user_apikey, customer_name, customer_type, body, project_name)
                                     'project_name': project_name,
                                     'customer_type': customer_type},
                            message_body=body)
-    rpc_queue.close()
     return value
 
 
@@ -301,7 +283,6 @@ def detect_missing_images(user_apikey, customer_name, customer_type, project, bo
                                     'project': project,
                                     'customer_type': customer_type},
                            message_body=str(body))
-    rpc_queue.close()
     return value
 
 @timeit
@@ -315,7 +296,6 @@ def get_historic(user_apikey, customer_name, customer_type, body, project_name,
                                     'project_name': project_name,
                                     'month_num': month_num},
                            message_body=body)
-    rpc_queue.close()
     return value
 
 
@@ -351,7 +331,6 @@ def get_list_all_clients_with_projects(body):
         'operation': 'get_list_all_clients_with_projects'
     },
         message_body=body)
-    rpc_queue.close()
     return value
 
 
@@ -362,7 +341,6 @@ def get_number_post_per_clients(body):
         'operation': 'get_number_post_per_clients'
     },
         message_body=body)
-    rpc_queue.close()
     return value
 
 
@@ -377,7 +355,6 @@ def update_user_apikey(customer_name, customer_type, body):
                                     },
                            message_body=body)
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -411,7 +388,6 @@ def get_specified_project_status(user_apikey, customer_name, customer_type, proj
                                     },
                            message_body=body)
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -428,7 +404,6 @@ def get_client_payment_status(customer_name, customer_type):
                            message_body="")
 
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 @timeit
@@ -445,7 +420,6 @@ def get_payment_status_for_client(user_apikey, customer_name, customer_type):
                            message_body="")
 
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -462,7 +436,6 @@ def get_client_statistics(user_apikey, customer_name, customer_type):
                                     },
                            message_body="")
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -476,7 +449,6 @@ def get_statistics_for_admin(customer_name, customer_type):
                                     'customer_type': customer_type},
                            message_body='')
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -489,7 +461,6 @@ def all_historic_users_management(body):
                                     },
                            message_body=body)
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -508,7 +479,6 @@ def get_details_trainings_for_client(user_apikey, customer_name, customer_type,
                            message_body="")
 
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -523,7 +493,6 @@ def get_details_trainings_for_admin(customer_name, customer_type, project_name):
                                     'project_name': project_name},
                            message_body='')
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -534,7 +503,6 @@ def all_historic_users_management_customer(body):
                           mqueue_password=MESSAGE_QUEUE_PASSWORD)
     value = rpc_queue.call(headers={'operation': 'all_historic_users_management_customer'}, message_body=body)
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -561,7 +529,6 @@ def can_create_users(customer_email, body, type_user, type_new_user, email, pass
                                     'user_apikey': ""},
                            message_body=body)
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -579,7 +546,6 @@ def can_delete_users(customer_email, body, type_user, email):
                                     'user_apikey': ""},
                            message_body=body)
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -603,7 +569,6 @@ def can_edit_users(customer_email, body, type_user, email, password, entreprise,
                                     'user_apikey': ""},
                            message_body=body)
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -620,7 +585,6 @@ def can_view_users(customer_email, body, type_user):
                                     'user_apikey': ""},
                            message_body=body)
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -637,7 +601,6 @@ def can_view_customers(customer_email, body, type_user):
                                     'user_apikey': ""},
                            message_body=body)
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -652,7 +615,6 @@ def can_update_apikey(customer_email, type_user, email, body):
                                     'email': email},
                            message_body=body)
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -669,7 +631,6 @@ def can_delete_project(customer_email, type_user, customer_name, customer_type,
                                     'customer_type': customer_type},
                            message_body=body)
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -686,7 +647,6 @@ def creation_entreprise_package(customer_email, type_user, plan_name, total, max
                                     'max_images_training': max_images_training},
                            message_body=body)
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -873,7 +833,6 @@ def get_connected_customer_cms_info(customer_name, customer_type, cms):
                                     'customer_type': customer_type,
                                     'cms': cms},
                            message_body='')
-    rpc_queue.close()
     return value.decode("utf-8")
 
 
@@ -885,7 +844,6 @@ def delete_user_data(customer_name, customer_type):
                                     'operation': 'delete_user_data'},
                            message_body="")
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 
@@ -896,7 +854,6 @@ def delete_user_data_from_email(customer_email):
                                     'operation': 'delete_user_data_from_email'},
                            message_body="")
     value = value.decode('utf-8')
-    rpc_queue.close()
     return value
 
 @timeit
